@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package JSON::Schema::Modern; # git description: v0.574-9-gade5d7e0
+package JSON::Schema::Modern; # git description: v0.575-4-ga39e2c20
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Validate data against a schema
 # KEYWORDS: JSON Schema validator data validation structure specification
 
-our $VERSION = '0.575';
+our $VERSION = '0.576';
 
 use 5.020;  # for fc, unicode_strings features
 use Moo;
@@ -1122,7 +1122,7 @@ JSON::Schema::Modern - Validate data against a schema
 
 =head1 VERSION
 
-version 0.575
+version 0.576
 
 =head1 SYNOPSIS
 
@@ -1248,8 +1248,7 @@ Defaults to false.
 =head2 stringy_numbers
 
 When true, any value that is expected to be a number or integer B<in the instance data> may also be
-expressed as a string. This does B<not> apply to the C<const> or C<enum> keywords, but only
-the following keywords:
+expressed as a string. This applies only to the following keywords:
 
 =over 4
 
@@ -1259,6 +1258,14 @@ C<type> (where both C<string> and C<number> (and possibly C<integer>) are consid
 
 =item *
 
+C<const> and C<enum> (where the string C<"1"> will match with C<"const": 1>)
+
+=item *
+
+C<uniqueItems> (where strings and numbers are compared numerically to each other, if either or both are numeric)
+
+=item *
+
 C<multipleOf>
 
 =item *
